@@ -16,6 +16,75 @@
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class AmsDetailInfo(AbstractModel):
+    """机器审核详情列表数据项
+
+    """
+
+    def __init__(self):
+        """
+        :param Label: 标签
+        :type Label: list of str
+        :param Duration: 时长(秒/s)
+        :type Duration: int
+        :param Name: 任务名
+        :type Name: str
+        :param TaskID: 任务ID，创建任务后返回的TaskId字段
+        :type TaskID: str
+        :param InsertTime: 插入时间
+        :type InsertTime: str
+        :param DataForm: 数据来源 0机审，其他为自主审核
+        :type DataForm: int
+        :param Operator: 操作人
+        :type Operator: str
+        :param OriginalLabel: 原始命中标签
+        :type OriginalLabel: list of str
+        :param OperateTime: 操作时间
+        :type OperateTime: str
+        :param Url: 视频原始地址
+        :type Url: str
+        :param Thumbnail: 封面图地址
+        :type Thumbnail: str
+        :param Content: 短音频内容
+        :type Content: str
+        :param DetailCount: 短音频个数
+        :type DetailCount: int
+        :param RequestId: 音频审核的请求 id
+        :type RequestId: str
+        """
+        self.Label = None
+        self.Duration = None
+        self.Name = None
+        self.TaskID = None
+        self.InsertTime = None
+        self.DataForm = None
+        self.Operator = None
+        self.OriginalLabel = None
+        self.OperateTime = None
+        self.Url = None
+        self.Thumbnail = None
+        self.Content = None
+        self.DetailCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Label = params.get("Label")
+        self.Duration = params.get("Duration")
+        self.Name = params.get("Name")
+        self.TaskID = params.get("TaskID")
+        self.InsertTime = params.get("InsertTime")
+        self.DataForm = params.get("DataForm")
+        self.Operator = params.get("Operator")
+        self.OriginalLabel = params.get("OriginalLabel")
+        self.OperateTime = params.get("OperateTime")
+        self.Url = params.get("Url")
+        self.Thumbnail = params.get("Thumbnail")
+        self.Content = params.get("Content")
+        self.DetailCount = params.get("DetailCount")
+        self.RequestId = params.get("RequestId")
+
+
 class AudioResult(AbstractModel):
     """音频输出参数
 
@@ -28,20 +97,12 @@ class AudioResult(AbstractModel):
 1 命中
 注意：此字段可能返回 null，表示取不到有效值。
         :type HitFlag: int
-        :param Label: 命中的标签
-Porn 色情
-Polity 政治
-Illegal 违法
-Abuse 谩骂
-Terror 暴恐
-Ad 广告
-Moan 呻吟
+        :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义词库。
+以及令人反感、不安全或不适宜的内容类型。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
-        :param Suggestion: 审核建议，可选值：
-Pass 通过，
-Review 建议人审，
-Block 确认违规
+        :param Suggestion: 建议您拿到判断结果后的执行操作。
+建议值，Block：建议屏蔽，Review：建议复审，Pass：建议通过
 注意：此字段可能返回 null，表示取不到有效值。
         :type Suggestion: str
         :param Score: 得分，0-100
@@ -57,11 +118,11 @@ Block 确认违规
         :type Duration: str
         :param Extra: 拓展字段
         :type Extra: str
-        :param TextResults: 文本审核结果
+        :param TextResults: 文本识别结果
         :type TextResults: list of AudioResultDetailTextResult
-        :param MoanResults: 音频呻吟审核结果
+        :param MoanResults: 音频呻吟检测结果
         :type MoanResults: list of AudioResultDetailMoanResult
-        :param LanguageResults: 音频语种检测结果
+        :param LanguageResults: 音频语言检测结果
         :type LanguageResults: list of AudioResultDetailLanguageResult
         """
         self.HitFlag = None
@@ -113,7 +174,7 @@ class AudioResultDetailLanguageResult(AbstractModel):
 
     def __init__(self):
         """
-        :param Label: 语种
+        :param Label: 语言信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
         :param Score: 得分
@@ -151,7 +212,7 @@ class AudioResultDetailMoanResult(AbstractModel):
 
     def __init__(self):
         """
-        :param Label: 固定为Moan
+        :param Label: 固定为Moan（呻吟）
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
         :param Score: 分数
@@ -425,6 +486,141 @@ class CreateBizConfigResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeAmsListRequest(AbstractModel):
+    """DescribeAmsList请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param PageToken: 页码
+        :type PageToken: str
+        :param Limit: 过滤条件
+        :type Limit: int
+        :param PageDirection: 查询方向
+        :type PageDirection: str
+        :param Filters: 过滤条件
+        :type Filters: list of Filter
+        """
+        self.PageToken = None
+        self.Limit = None
+        self.PageDirection = None
+        self.Filters = None
+
+
+    def _deserialize(self, params):
+        self.PageToken = params.get("PageToken")
+        self.Limit = params.get("Limit")
+        self.PageDirection = params.get("PageDirection")
+        if params.get("Filters") is not None:
+            self.Filters = []
+            for item in params.get("Filters"):
+                obj = Filter()
+                obj._deserialize(item)
+                self.Filters.append(obj)
+
+
+class DescribeAmsListResponse(AbstractModel):
+    """DescribeAmsList返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param AmsDetailSet: 返回列表数据----非必选，该参数暂未对外开放
+        :type AmsDetailSet: list of AmsDetailInfo
+        :param Total: 总条数
+        :type Total: int
+        :param PageToken: 分页 token
+        :type PageToken: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.AmsDetailSet = None
+        self.Total = None
+        self.PageToken = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("AmsDetailSet") is not None:
+            self.AmsDetailSet = []
+            for item in params.get("AmsDetailSet"):
+                obj = AmsDetailInfo()
+                obj._deserialize(item)
+                self.AmsDetailSet.append(obj)
+        self.Total = params.get("Total")
+        self.PageToken = params.get("PageToken")
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeAudioStatRequest(AbstractModel):
+    """DescribeAudioStat请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param AuditType: 审核类型 1: 机器审核; 2: 人工审核
+        :type AuditType: int
+        :param Filters: 查询条件
+        :type Filters: list of Filters
+        """
+        self.AuditType = None
+        self.Filters = None
+
+
+    def _deserialize(self, params):
+        self.AuditType = params.get("AuditType")
+        if params.get("Filters") is not None:
+            self.Filters = []
+            for item in params.get("Filters"):
+                obj = Filters()
+                obj._deserialize(item)
+                self.Filters.append(obj)
+
+
+class DescribeAudioStatResponse(AbstractModel):
+    """DescribeAudioStat返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Overview: 识别结果统计
+        :type Overview: :class:`tencentcloud.ams.v20200608.models.Overview`
+        :param TrendCount: 识别量统计
+        :type TrendCount: list of TrendCount
+        :param EvilCount: 违规数据分布
+        :type EvilCount: list of EvilCount
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Overview = None
+        self.TrendCount = None
+        self.EvilCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Overview") is not None:
+            self.Overview = Overview()
+            self.Overview._deserialize(params.get("Overview"))
+        if params.get("TrendCount") is not None:
+            self.TrendCount = []
+            for item in params.get("TrendCount"):
+                obj = TrendCount()
+                obj._deserialize(item)
+                self.TrendCount.append(obj)
+        if params.get("EvilCount") is not None:
+            self.EvilCount = []
+            for item in params.get("EvilCount"):
+                obj = EvilCount()
+                obj._deserialize(item)
+                self.EvilCount.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeBizConfigRequest(AbstractModel):
     """DescribeBizConfig请求参数结构体
 
@@ -634,6 +830,27 @@ Block 建议屏蔽；
         self.RequestId = params.get("RequestId")
 
 
+class EvilCount(AbstractModel):
+    """违规数据分布
+
+    """
+
+    def __init__(self):
+        """
+        :param EvilType: ----非必选，该参数功能暂未对外开放
+        :type EvilType: str
+        :param Count: 分布类型总量
+        :type Count: int
+        """
+        self.EvilType = None
+        self.Count = None
+
+
+    def _deserialize(self, params):
+        self.EvilType = params.get("EvilType")
+        self.Count = params.get("Count")
+
+
 class FileOutput(AbstractModel):
     """Cos FileOutput
 
@@ -659,6 +876,51 @@ class FileOutput(AbstractModel):
         self.ObjectPrefix = params.get("ObjectPrefix")
 
 
+class Filter(AbstractModel):
+    """描述键值对过滤器，用于条件过滤查询。例如过滤ID、名称、状态等
+
+    """
+
+    def __init__(self):
+        """
+        :param Name: 过滤键的名称。
+        :type Name: str
+        :param Values: 一个或者多个过滤值。
+        :type Values: list of str
+        """
+        self.Name = None
+        self.Values = None
+
+
+    def _deserialize(self, params):
+        self.Name = params.get("Name")
+        self.Values = params.get("Values")
+
+
+class Filters(AbstractModel):
+    """音频过滤条件
+
+    """
+
+    def __init__(self):
+        """
+        :param Name: 查询字段：
+策略BizType
+子账号SubUin
+日期区间DateRange
+        :type Name: str
+        :param Values: 查询值
+        :type Values: list of str
+        """
+        self.Name = None
+        self.Values = None
+
+
+    def _deserialize(self, params):
+        self.Name = params.get("Name")
+        self.Values = params.get("Values")
+
+
 class ImageResult(AbstractModel):
     """Result结果详情
 
@@ -671,21 +933,13 @@ class ImageResult(AbstractModel):
 1 命中
 注意：此字段可能返回 null，表示取不到有效值。
         :type HitFlag: int
-        :param Label: 命中的标签
-Porn 色情
-Sexy 性感
-Polity 政治
-Illegal 违法
-Abuse 谩骂
-Terror 暴恐
-Ad 广告
+        :param Suggestion: 建议您拿到判断结果后的执行操作。
+建议值，Block：建议屏蔽，Review：建议复审，Pass：建议通过
+        :type Suggestion: str
+        :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义词库。
+以及令人反感、不安全或不适宜的内容类型。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
-        :param Suggestion: 审核建议，可选值：
-Pass 通过，
-Review 建议人审，
-Block 确认违规
-        :type Suggestion: str
         :param Score: 得分
         :type Score: int
         :param Results: 画面截帧图片结果集
@@ -696,8 +950,8 @@ Block 确认违规
         :type Extra: str
         """
         self.HitFlag = None
-        self.Label = None
         self.Suggestion = None
+        self.Label = None
         self.Score = None
         self.Results = None
         self.Url = None
@@ -706,8 +960,8 @@ Block 确认违规
 
     def _deserialize(self, params):
         self.HitFlag = params.get("HitFlag")
-        self.Label = params.get("Label")
         self.Suggestion = params.get("Suggestion")
+        self.Label = params.get("Label")
         self.Score = params.get("Score")
         if params.get("Results") is not None:
             self.Results = []
@@ -729,11 +983,9 @@ class ImageResultResult(AbstractModel):
         :param Scene: 场景
 Porn 色情
 Sexy 性感
-Polity 政治
-Illegal 违法
 Abuse 谩骂
-Terror 暴恐
 Ad 广告
+等多个识别场景
 注意：此字段可能返回 null，表示取不到有效值。
         :type Scene: str
         :param HitFlag: 是否命中
@@ -741,10 +993,8 @@ Ad 广告
 1 命中
 注意：此字段可能返回 null，表示取不到有效值。
         :type HitFlag: int
-        :param Suggestion: 审核建议，可选值：
-Pass 通过，
-Review 建议人审，
-Block 确认违规
+        :param Suggestion: 建议您拿到判断结果后的执行操作。
+建议值，Block：建议屏蔽，Review：建议复审，Pass：建议通过
 注意：此字段可能返回 null，表示取不到有效值。
         :type Suggestion: str
         :param Label: 标签
@@ -968,11 +1218,14 @@ class MediaInfo(AbstractModel):
         :type Width: int
         :param Height: 高，单位为像素
         :type Height: int
+        :param Thumbnail: 缩略图
+        :type Thumbnail: str
         """
         self.Codecs = None
         self.Duration = None
         self.Width = None
         self.Height = None
+        self.Thumbnail = None
 
 
     def _deserialize(self, params):
@@ -980,6 +1233,7 @@ class MediaInfo(AbstractModel):
         self.Duration = params.get("Duration")
         self.Width = params.get("Width")
         self.Height = params.get("Height")
+        self.Thumbnail = params.get("Thumbnail")
 
 
 class MediaModerationConfig(AbstractModel):
@@ -1021,6 +1275,51 @@ class MediaModerationConfig(AbstractModel):
         self.UseAudio = params.get("UseAudio")
 
 
+class Overview(AbstractModel):
+    """识别结果统计
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalCount: 总调用量
+        :type TotalCount: int
+        :param TotalHour: 总调用时长
+        :type TotalHour: int
+        :param PassCount: 通过量
+        :type PassCount: int
+        :param PassHour: 通过时长
+        :type PassHour: int
+        :param EvilCount: 违规量
+        :type EvilCount: int
+        :param EvilHour: 违规时长
+        :type EvilHour: int
+        :param SuspectCount: 疑似违规量
+        :type SuspectCount: int
+        :param SuspectHour: 疑似违规时长
+        :type SuspectHour: int
+        """
+        self.TotalCount = None
+        self.TotalHour = None
+        self.PassCount = None
+        self.PassHour = None
+        self.EvilCount = None
+        self.EvilHour = None
+        self.SuspectCount = None
+        self.SuspectHour = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        self.TotalHour = params.get("TotalHour")
+        self.PassCount = params.get("PassCount")
+        self.PassHour = params.get("PassHour")
+        self.EvilCount = params.get("EvilCount")
+        self.EvilHour = params.get("EvilHour")
+        self.SuspectCount = params.get("SuspectCount")
+        self.SuspectHour = params.get("SuspectHour")
+
+
 class StorageInfo(AbstractModel):
     """数据存储信息
 
@@ -1084,20 +1383,12 @@ class TaskLabel(AbstractModel):
 
     def __init__(self):
         """
-        :param Label: 命中的标签
-Porn 色情
-Sexy 性感
-Polity 政治
-Illegal 违法
-Abuse 谩骂
-Terror 暴恐
-Ad 广告
+        :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义词库。
+以及令人反感、不安全或不适宜的内容类型。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
-        :param Suggestion: 审核建议，可选值：
-Pass 通过，
-Review 建议人审，
-Block 确认违规
+        :param Suggestion: 建议您拿到判断结果后的执行操作。
+建议值，Block：建议屏蔽，Review：建议复审，Pass：建议通过
 注意：此字段可能返回 null，表示取不到有效值。
         :type Suggestion: str
         :param Score: 得分，分数是 0 ～ 100
@@ -1145,4 +1436,53 @@ class TaskResult(AbstractModel):
         self.DataId = params.get("DataId")
         self.TaskId = params.get("TaskId")
         self.Code = params.get("Code")
-        self.Message = params.get("Message")
\ No newline at end of file
+        self.Message = params.get("Message")
+
+
+class TrendCount(AbstractModel):
+    """识别量统计
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalCount: 总调用量
+        :type TotalCount: int
+        :param TotalHour: 总调用时长
+        :type TotalHour: int
+        :param PassCount: 通过量
+        :type PassCount: int
+        :param PassHour: 通过时长
+        :type PassHour: int
+        :param EvilCount: 违规量
+        :type EvilCount: int
+        :param EvilHour: 违规时长
+        :type EvilHour: int
+        :param SuspectCount: 疑似违规量
+        :type SuspectCount: int
+        :param SuspectHour: 疑似违规时长
+        :type SuspectHour: int
+        :param Date: 日期
+        :type Date: str
+        """
+        self.TotalCount = None
+        self.TotalHour = None
+        self.PassCount = None
+        self.PassHour = None
+        self.EvilCount = None
+        self.EvilHour = None
+        self.SuspectCount = None
+        self.SuspectHour = None
+        self.Date = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        self.TotalHour = params.get("TotalHour")
+        self.PassCount = params.get("PassCount")
+        self.PassHour = params.get("PassHour")
+        self.EvilCount = params.get("EvilCount")
+        self.EvilHour = params.get("EvilHour")
+        self.SuspectCount = params.get("SuspectCount")
+        self.SuspectHour = params.get("SuspectHour")
+        self.Date = params.get("Date")
\ No newline at end of file
