@@ -278,6 +278,8 @@ class CreateLoRaGatewayRequest(AbstractModel):
         :type PositionDetails: str
         :param IsPublic: 是否公开
         :type IsPublic: bool
+        :param FrequencyId: 频点ID
+        :type FrequencyId: str
         """
         self.GatewayId = None
         self.Name = None
@@ -286,6 +288,7 @@ class CreateLoRaGatewayRequest(AbstractModel):
         self.Position = None
         self.PositionDetails = None
         self.IsPublic = None
+        self.FrequencyId = None
 
 
     def _deserialize(self, params):
@@ -298,6 +301,7 @@ class CreateLoRaGatewayRequest(AbstractModel):
         self.Position = params.get("Position")
         self.PositionDetails = params.get("PositionDetails")
         self.IsPublic = params.get("IsPublic")
+        self.FrequencyId = params.get("FrequencyId")
 
 
 class CreateLoRaGatewayResponse(AbstractModel):
@@ -435,6 +439,46 @@ class CreateStudioProductResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateTopicRuleRequest(AbstractModel):
+    """CreateTopicRule请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RuleName: 规则名称
+        :type RuleName: str
+        :param TopicRulePayload: 规则内容
+        :type TopicRulePayload: :class:`tencentcloud.iotexplorer.v20190423.models.TopicRulePayload`
+        """
+        self.RuleName = None
+        self.TopicRulePayload = None
+
+
+    def _deserialize(self, params):
+        self.RuleName = params.get("RuleName")
+        if params.get("TopicRulePayload") is not None:
+            self.TopicRulePayload = TopicRulePayload()
+            self.TopicRulePayload._deserialize(params.get("TopicRulePayload"))
+
+
+class CreateTopicRuleResponse(AbstractModel):
+    """CreateTopicRule返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DeleteDeviceRequest(AbstractModel):
     """DeleteDevice请求参数结构体
 
@@ -585,6 +629,40 @@ class DeleteStudioProductResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DeleteTopicRuleRequest(AbstractModel):
+    """DeleteTopicRule请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RuleName: 规则名
+        :type RuleName: str
+        """
+        self.RuleName = None
+
+
+    def _deserialize(self, params):
+        self.RuleName = params.get("RuleName")
+
+
+class DeleteTopicRuleResponse(AbstractModel):
+    """DeleteTopicRule返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeDeviceDataHistoryRequest(AbstractModel):
     """DescribeDeviceDataHistory请求参数结构体
 
@@ -882,6 +960,47 @@ class DescribeStudioProductResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeTopicRuleRequest(AbstractModel):
+    """DescribeTopicRule请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RuleName: 规则名称。
+        :type RuleName: str
+        """
+        self.RuleName = None
+
+
+    def _deserialize(self, params):
+        self.RuleName = params.get("RuleName")
+
+
+class DescribeTopicRuleResponse(AbstractModel):
+    """DescribeTopicRule返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Rule: 规则描述。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Rule: :class:`tencentcloud.iotexplorer.v20190423.models.TopicRule`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Rule = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Rule") is not None:
+            self.Rule = TopicRule()
+            self.Rule._deserialize(params.get("Rule"))
+        self.RequestId = params.get("RequestId")
+
+
 class DeviceData(AbstractModel):
     """DeviceData
 
@@ -1017,6 +1136,74 @@ class DeviceInfo(AbstractModel):
         self.NwkSKey = params.get("NwkSKey")
 
 
+class DisableTopicRuleRequest(AbstractModel):
+    """DisableTopicRule请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RuleName: 规则名称
+        :type RuleName: str
+        """
+        self.RuleName = None
+
+
+    def _deserialize(self, params):
+        self.RuleName = params.get("RuleName")
+
+
+class DisableTopicRuleResponse(AbstractModel):
+    """DisableTopicRule返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
+class EnableTopicRuleRequest(AbstractModel):
+    """EnableTopicRule请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RuleName: 规则名称
+        :type RuleName: str
+        """
+        self.RuleName = None
+
+
+    def _deserialize(self, params):
+        self.RuleName = params.get("RuleName")
+
+
+class EnableTopicRuleResponse(AbstractModel):
+    """EnableTopicRule返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class EventHistoryItem(AbstractModel):
     """设备事件的搜索结果项
 
@@ -1293,6 +1480,57 @@ class GetStudioProductListResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class GetTopicRuleListRequest(AbstractModel):
+    """GetTopicRuleList请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param PageNum: 请求的页数
+        :type PageNum: int
+        :param PageSize: 分页的大小
+        :type PageSize: int
+        """
+        self.PageNum = None
+        self.PageSize = None
+
+
+    def _deserialize(self, params):
+        self.PageNum = params.get("PageNum")
+        self.PageSize = params.get("PageSize")
+
+
+class GetTopicRuleListResponse(AbstractModel):
+    """GetTopicRuleList返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalCnt: 规则总数量
+        :type TotalCnt: int
+        :param Rules: 规则列表
+        :type Rules: list of TopicRuleInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TotalCnt = None
+        self.Rules = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCnt = params.get("TotalCnt")
+        if params.get("Rules") is not None:
+            self.Rules = []
+            for item in params.get("Rules"):
+                obj = TopicRuleInfo()
+                obj._deserialize(item)
+                self.Rules.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class ListEventHistoryRequest(AbstractModel):
     """ListEventHistory请求参数结构体
 
@@ -1312,7 +1550,7 @@ class ListEventHistoryRequest(AbstractModel):
         :type EndTime: int
         :param Context: 搜索上下文, 用作查询游标
         :type Context: str
-        :param Size: 单次获取的历史数据项目的最大数量
+        :param Size: 单次获取的历史数据项目的最大数量, 缺省10
         :type Size: int
         :param EventId: 事件标识符，可以用来指定查询特定的事件，如果不指定，则查询所有事件。
         :type EventId: str
@@ -1407,6 +1645,8 @@ class LoRaGatewayItem(AbstractModel):
         :type CreatedAt: str
         :param LastSeenAt: 最后上报时间
         :type LastSeenAt: str
+        :param FrequencyId: 频点ID
+        :type FrequencyId: str
         """
         self.GatewayId = None
         self.IsPublic = None
@@ -1418,6 +1658,7 @@ class LoRaGatewayItem(AbstractModel):
         self.UpdatedAt = None
         self.CreatedAt = None
         self.LastSeenAt = None
+        self.FrequencyId = None
 
 
     def _deserialize(self, params):
@@ -1433,6 +1674,7 @@ class LoRaGatewayItem(AbstractModel):
         self.UpdatedAt = params.get("UpdatedAt")
         self.CreatedAt = params.get("CreatedAt")
         self.LastSeenAt = params.get("LastSeenAt")
+        self.FrequencyId = params.get("FrequencyId")
 
 
 class LoRaGatewayLocation(AbstractModel):
@@ -1485,6 +1727,8 @@ class ModifyLoRaGatewayRequest(AbstractModel):
         :type Position: str
         :param PositionDetails: 位置详情
         :type PositionDetails: str
+        :param FrequencyId: 频点ID
+        :type FrequencyId: str
         """
         self.Description = None
         self.GatewayId = None
@@ -1493,6 +1737,7 @@ class ModifyLoRaGatewayRequest(AbstractModel):
         self.IsPublic = None
         self.Position = None
         self.PositionDetails = None
+        self.FrequencyId = None
 
 
     def _deserialize(self, params):
@@ -1505,6 +1750,7 @@ class ModifyLoRaGatewayRequest(AbstractModel):
         self.IsPublic = params.get("IsPublic")
         self.Position = params.get("Position")
         self.PositionDetails = params.get("PositionDetails")
+        self.FrequencyId = params.get("FrequencyId")
 
 
 class ModifyLoRaGatewayResponse(AbstractModel):
@@ -1672,6 +1918,46 @@ class ModifyStudioProductResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class ModifyTopicRuleRequest(AbstractModel):
+    """ModifyTopicRule请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RuleName: 规则名称
+        :type RuleName: str
+        :param TopicRulePayload: 替换的规则包体
+        :type TopicRulePayload: :class:`tencentcloud.iotexplorer.v20190423.models.TopicRulePayload`
+        """
+        self.RuleName = None
+        self.TopicRulePayload = None
+
+
+    def _deserialize(self, params):
+        self.RuleName = params.get("RuleName")
+        if params.get("TopicRulePayload") is not None:
+            self.TopicRulePayload = TopicRulePayload()
+            self.TopicRulePayload._deserialize(params.get("TopicRulePayload"))
+
+
+class ModifyTopicRuleResponse(AbstractModel):
+    """ModifyTopicRule返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class ProductEntry(AbstractModel):
     """产品详情
 
@@ -1858,6 +2144,60 @@ class ProjectEntryEx(AbstractModel):
         self.WebAppCount = params.get("WebAppCount")
 
 
+class PublishMessageRequest(AbstractModel):
+    """PublishMessage请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ProductId: 产品ID
+        :type ProductId: str
+        :param DeviceName: 设备名称
+        :type DeviceName: str
+        :param Topic: 消息发往的主题
+        :type Topic: str
+        :param Payload: 云端下发到设备的控制报文
+        :type Payload: str
+        :param Qos: 消息服务质量等级，取值为0或1
+        :type Qos: int
+        :param PayloadEncoding: Payload的内容编码格式，取值为base64或空。base64表示云端将接收到的base64编码后的报文再转换成二进制报文下发至设备，为空表示不作转换，透传下发至设备
+        :type PayloadEncoding: str
+        """
+        self.ProductId = None
+        self.DeviceName = None
+        self.Topic = None
+        self.Payload = None
+        self.Qos = None
+        self.PayloadEncoding = None
+
+
+    def _deserialize(self, params):
+        self.ProductId = params.get("ProductId")
+        self.DeviceName = params.get("DeviceName")
+        self.Topic = params.get("Topic")
+        self.Payload = params.get("Payload")
+        self.Qos = params.get("Qos")
+        self.PayloadEncoding = params.get("PayloadEncoding")
+
+
+class PublishMessageResponse(AbstractModel):
+    """PublishMessage返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class ReleaseStudioProductRequest(AbstractModel):
     """ReleaseStudioProduct请求参数结构体
 
@@ -1956,4 +2296,193 @@ class SearchStudioProductResponse(AbstractModel):
                 obj._deserialize(item)
                 self.Products.append(obj)
         self.Total = params.get("Total")
-        self.RequestId = params.get("RequestId")
\ No newline at end of file
+        self.RequestId = params.get("RequestId")
+
+
+class SearchTopicRuleRequest(AbstractModel):
+    """SearchTopicRule请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RuleName: 规则名
+        :type RuleName: str
+        """
+        self.RuleName = None
+
+
+    def _deserialize(self, params):
+        self.RuleName = params.get("RuleName")
+
+
+class SearchTopicRuleResponse(AbstractModel):
+    """SearchTopicRule返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalCnt: 搜索到的规则总数
+        :type TotalCnt: int
+        :param Rules: 规则信息列表
+        :type Rules: list of TopicRuleInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TotalCnt = None
+        self.Rules = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCnt = params.get("TotalCnt")
+        if params.get("Rules") is not None:
+            self.Rules = []
+            for item in params.get("Rules"):
+                obj = TopicRuleInfo()
+                obj._deserialize(item)
+                self.Rules.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
+class TopicRule(AbstractModel):
+    """TopicRule结构
+
+    """
+
+    def __init__(self):
+        """
+        :param RuleName: 规则名称。
+        :type RuleName: str
+        :param Sql: 规则的SQL语句，如： SELECT * FROM 'pid/dname/event'，然后对其进行base64编码，得：U0VMRUNUICogRlJPTSAncGlkL2RuYW1lL2V2ZW50Jw==
+        :type Sql: str
+        :param Description: 规则描述。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Description: str
+        :param Actions: 行为的JSON字符串。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Actions: str
+        :param RuleDisabled: 是否禁用规则
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RuleDisabled: bool
+        """
+        self.RuleName = None
+        self.Sql = None
+        self.Description = None
+        self.Actions = None
+        self.RuleDisabled = None
+
+
+    def _deserialize(self, params):
+        self.RuleName = params.get("RuleName")
+        self.Sql = params.get("Sql")
+        self.Description = params.get("Description")
+        self.Actions = params.get("Actions")
+        self.RuleDisabled = params.get("RuleDisabled")
+
+
+class TopicRuleInfo(AbstractModel):
+    """规则信息
+
+    """
+
+    def __init__(self):
+        """
+        :param RuleName: 规则名称
+        :type RuleName: str
+        :param Description: 规则描述
+        :type Description: str
+        :param CreatedAt: 创建时间
+        :type CreatedAt: int
+        :param RuleDisabled: 规则是否禁用
+        :type RuleDisabled: bool
+        """
+        self.RuleName = None
+        self.Description = None
+        self.CreatedAt = None
+        self.RuleDisabled = None
+
+
+    def _deserialize(self, params):
+        self.RuleName = params.get("RuleName")
+        self.Description = params.get("Description")
+        self.CreatedAt = params.get("CreatedAt")
+        self.RuleDisabled = params.get("RuleDisabled")
+
+
+class TopicRulePayload(AbstractModel):
+    """TopicRulePayload结构
+
+    """
+
+    def __init__(self):
+        """
+        :param Sql: 规则的SQL语句，如： SELECT * FROM 'pid/dname/event'，然后对其进行base64编码，得：U0VMRUNUICogRlJPTSAncGlkL2RuYW1lL2V2ZW50Jw==
+        :type Sql: str
+        :param Actions: 行为的JSON字符串，大部分种类举例如下：
+[
+{
+"republish": {
+"topic": "TEST/test"
+}
+},
+{
+"forward": {
+"api": "http://127.0.0.1:8080"
+}
+},
+{
+"ckafka": {
+"instance": {
+"id": "ckafka-test",
+"name": ""
+},
+"topic": {
+"id": "topic-test",
+"name": "test"
+},
+"region": "gz"
+}
+},
+{
+"cmqqueue": {
+"queuename": "queue-test-TEST",
+"region": "gz"
+}
+},
+{
+"mysql": {
+"instanceid": "cdb-test",
+"region": "gz",
+"username": "test",
+"userpwd": "*****",
+"dbname": "d_mqtt",
+"tablename": "t_test",
+"fieldpairs": [
+{
+"field": "test",
+"value": "test"
+}
+],
+"devicetype": "CUSTOM"
+}
+}
+]
+        :type Actions: str
+        :param Description: 规则描述
+        :type Description: str
+        :param RuleDisabled: 是否禁用规则
+        :type RuleDisabled: bool
+        """
+        self.Sql = None
+        self.Actions = None
+        self.Description = None
+        self.RuleDisabled = None
+
+
+    def _deserialize(self, params):
+        self.Sql = params.get("Sql")
+        self.Actions = params.get("Actions")
+        self.Description = params.get("Description")
+        self.RuleDisabled = params.get("RuleDisabled")
\ No newline at end of file
